@@ -23,10 +23,11 @@ class Plugin(object):
             self.project.close()
             self.hints_monitor.cancel()
     
-    def refresh_hints(self, filemonitor, file, other_file, event, db):
+    def refresh_hints(self, filemonitor, file, other_file, event, db, project):
         if event in (gio.FILE_MONITOR_EVENT_CHANGES_DONE_HINT, gio.FILE_MONITOR_EVENT_CREATED):        
             db.refresh()
-    
+            project.pycore.module_cache.forget_all_data()
+
     @lazy_property
     def project(self):
         if not os.access(self.editor.uri, os.W_OK):
@@ -40,7 +41,7 @@ class Plugin(object):
             db = FileHintDb(project)
 
             self.hints_monitor = gio.File(db.hints_filename).monitor_file()
-            self.hints_monitor.connect('changed', self.refresh_hints, db)
+            self.hints_monitor.connect('changed', self.refresh_hints, db, project)
             
             return project
         else:
@@ -71,6 +72,40 @@ class Plugin(object):
         iterator = edit.get_iter_at_line(line - 1)
         edit.place_cursor(iterator)
         editor.view.scroll_to_iter(iterator, 0.001, use_align=True, xalign=1.0)
+    
+    def get_fuzzy_location(self, source, offset):
+        from rope.base import worder, exceptions
+        
+        word_finder = worder.Worder(source, True)
+        expression = word_finder.get_primary_at(offset)
+        expression = expression.replace('\\\n', ' ').replace('\n', ' ')
+        
+        names = expression.split('.')
+        pyname = None
+        try:
+            obj = self.project.pycore.get_module(names[0])
+            for n in names[1:]:
+                pyname = obj[n]
+                obj = pyname.get_object()
+        except (exceptions.ModuleNotFoundError, exceptions.AttributeNotFoundError):
+            return None, None
+   
+        if not pyname:
+            try:
+                resource = obj._get_init_dot_py()
+            except AttributeError:
+                resource = obj.get_resource()
+            
+            if not resource:
+                return None, None
+            else:
+                return resource, 1
+        else:
+            resource, line = pyname.get_definition_location()
+            if hasattr(resource, 'resource'):
+                resource = resource.resource
+            
+        return resource, line
 
     def goto_definition(self):
         project = self.project
@@ -81,29 +116,32 @@ class Plugin(object):
                 return
         
         project.validate()
-                 
+
         current_resource = self.get_rope_resource(project) 
         
         from rope.contrib import codeassist
 
+        source, offset = self.get_source_and_offset()
         try:
             resource, line = codeassist.get_definition_location(
-                project, *self.get_source_and_offset(),
+                project, source, offset,
                 resource=current_resource, maxfixes=3)
         except Exception, e:
             import traceback
             traceback.print_exc()
             self.editor.message(str(e), 5000)
             return
+
+        if resource is None and line is None:
+            resource, line = self.get_fuzzy_location(source, offset)
         
         if resource and resource.real_path == current_resource.real_path:
             resource = None
             
         if resource:
             uri = resource.real_path
-            editor = self.editor.open_file(uri)
+            editor = self.editor.open_file(uri, line-1)
             editor.ropeproject = project 
-            self.goto_line(editor, line)
         else:
             if line:
                 self.goto_line(self.editor, line)
