@@ -9,9 +9,18 @@ import rope.base.pynames
 from rope.base import exceptions
 from rope.base.pyobjectsdef import PyModule, PyPackage
 
-def update_type_for(project, source, resource):
-    pass
-    
+class ReplacedName(rope.base.pynames.PyName):
+    def __init__(self, pyobject, pyname):
+        self.pyobject = pyobject
+        self.pyname = pyname
+
+    def get_object(self):
+        return self.pyobject
+
+    def get_definition_location(self):
+        return self.pyname.get_definition_location()
+
+
 def infer_parameter_objects_with_hints(func):
     def inner(pyfunction):
         params_types = func(pyfunction)
@@ -89,9 +98,11 @@ class HintDb(object):
         scope_path = self.get_scope_path(pyfunc.get_scope())
         type_name = self.find_type_for(scope_path, name)
         if type_name:
-            return self.get_type(pyfunc.pycore, type_name).get_object()
-        else:
-            return None
+            pyname = self.get_type(pyfunc.pycore, type_name)
+            if pyname:
+                return pyname.get_object()
+        
+        return None
         
     def get_scope_path(self, scope):
         result = []
@@ -120,12 +131,15 @@ class HintDb(object):
         module, sep, name = type_name.strip('()').rpartition('.')
         if module:
             module = pycore.get_module(module)
-            obj = module[name]
+            try:
+                pyname = module[name]
+            except exceptions.AttributeNotFoundError:
+                pyname = None
         else:
-            obj = pycore.get_module(name)
+            pyname = pycore.get_module(name)
         
-        self.type_cache[type_name] = obj
-        return obj
+        self.type_cache[type_name] = pyname
+        return pyname
         
     def get_module_attribute(self, pymodule, name, original_pyname):
         try:
@@ -142,14 +156,8 @@ class HintDb(object):
         
         if type:
             if type_name.endswith('()'):
-                type = type.get_object()
-                
-                obj = rope.base.pyobjects.PyObject(type)
-                if isinstance(original_pyname, rope.base.pynamesdef.AssignedName):
-                    pyname = rope.base.pynamesdef.AssignedName(original_pyname.lineno,
-                        original_pyname.module, obj)
-                else:
-                    pyname = rope.base.pynames.DefinedName(obj)
+                obj = rope.base.pyobjects.PyObject(type.get_object())
+                pyname = ReplacedName(obj, type)
             else:
                 pyname = type
         else:
@@ -169,7 +177,8 @@ class ReHintDb(HintDb):
 
     def find_type_for(self, scope_path, name):
         for scope, vname, otype in self.db:
-            if scope.search(scope_path) and vname.search(name):
+            if scope.match(scope_path) and vname.match(name):
+                #print 'matched', scope_path, name
                 return otype
                 
         return None
@@ -186,6 +195,7 @@ class FileHintDb(ReHintDb):
     def load_hints(self):
         self.db[:] = []
         self.module_attrs_cache.clear()
+        self.type_cache.clear()
         
         if os.path.exists(self.hints_filename):
             with open(self.hints_filename) as f:
